@@ -272,7 +272,7 @@ void set_zero_entries(GtkWidget *widget, gpointer data)
 
 static void draw_policy(gint idx)
 {
-	GtkWidget *button, *button2, *button3;
+	GtkWidget *button, *button2, *button3, *button4;
 
 	button = gtk_radio_button_new_with_label(NULL, IP_FW_LABEL_ACCEPT);
 	gtk_box_pack_start(GTK_BOX(fwchain[idx].hbox), button, FALSE, FALSE, 2);
@@ -289,13 +289,24 @@ static void draw_policy(gint idx)
 			IP_FW_LABEL_REJECT);
 	gtk_box_pack_start(GTK_BOX(fwchain[idx].hbox), button3,FALSE,FALSE, 2);
 	gtk_widget_show(button3);
+
+	if(!strcmp(fwchain[idx].label, IP_FW_LABEL_FORWARD)) {
+		button4 = gtk_radio_button_new_with_label(
+			gtk_radio_button_group(GTK_RADIO_BUTTON(button3)),
+			IP_FW_LABEL_MASQUERADE);
+		gtk_box_pack_start(GTK_BOX(fwchain[idx].hbox),
+						button4,FALSE,FALSE, 2);
+		gtk_widget_show(button4);
+	}
 	
 	if(!strcmp(fwchain[idx].policy, IP_FW_LABEL_ACCEPT))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 	else if(!strcmp(fwchain[idx].policy, IP_FW_LABEL_BLOCK))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button2), TRUE);
-	else
+	else if(!strcmp(fwchain[idx].policy, IP_FW_LABEL_REJECT))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button3), TRUE);
+	else
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button4), TRUE);
 
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 			GTK_SIGNAL_FUNC(set_fwpolicy_data), IP_FW_LABEL_ACCEPT);
@@ -303,6 +314,11 @@ static void draw_policy(gint idx)
 			GTK_SIGNAL_FUNC(set_fwpolicy_data), IP_FW_LABEL_BLOCK);
 	gtk_signal_connect(GTK_OBJECT(button3), "clicked",
 			GTK_SIGNAL_FUNC(set_fwpolicy_data), IP_FW_LABEL_REJECT);
+	if(!strcmp(fwchain[idx].label, IP_FW_LABEL_FORWARD)) {
+		gtk_signal_connect(GTK_OBJECT(button4), "clicked",
+				   GTK_SIGNAL_FUNC(set_fwpolicy_data),
+				   IP_FW_LABEL_MASQUERADE);
+	}
 }
 
 #define _IPFWC_FMT2(i) "%" #i "s "
